NEO_CheckOne = function(oValue)
-- returns true if oValue is 1

	return oValue == 1
end


CheckCreaturesForCharacteristic = function(nCharacteristic)
-- returns 1 if there is at least one creature on battlefield  with the ability nCharacteristic (not considering EffectSource card) 
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add(FE_TYPE, OP_IS, CARD_TYPE_CREATURE)
  oFilter:Add(FE_CHARACTERISTIC, OP_HAS, nCharacteristic)
  oFilter:Add(FE_CARD_INSTANCE, OP_NOT, EffectSource())
  if (oFilter:Count() > 0) then
    return 1
  end
  return 0
end


CheckCreaturesForCharacteristicControlledBy = function(nCharacteristic, nPlayer)
-- returns 1 if there is at least one creature on battlefield controlled by nPlayer with the ability nCharacteristic.
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add(FE_TYPE, OP_IS, CARD_TYPE_CREATURE)
  oFilter:Add(FE_CHARACTERISTIC, OP_HAS, nCharacteristic)
  oFilter:Add(FE_CONTROLLER, OP_IS, nPlayer)
  if (oFilter:Count() > 0) then
    return 1
  end
  return 0
end

CheckCreaturesForCharacteristicControlledByOpponents = function(nCharacteristic)
-- returns 1 if there is at least one creature on battlefield controlled by opponents with the ability nCharacteristic.
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add(FE_TYPE, OP_IS, CARD_TYPE_CREATURE)
  oFilter:Add(FE_CHARACTERISTIC, OP_HAS, nCharacteristic)
  oFilter:Add( FE_TEAM, OP_NOT, EffectController():GetTeam() )
  if (oFilter:Count() > 0) then
    return 1
  end
  return 0
end

CheckSourceForCharacteristic = function(nCharacteristic)
-- returns 1 if EffectSource card  has the ability nCharacteristic 
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add(FE_TYPE, OP_IS, CARD_TYPE_CREATURE)
  oFilter:Add(FE_CHARACTERISTIC, OP_HAS, nCharacteristic)
  oFilter:Add(FE_CARD_INSTANCE, OP_IS, EffectSource())
  if (oFilter:Count() > 0) then
    return 1
  end
  return 0
end

CheckThisCreatureForCharacteristic = function(nCharacteristic, nCreature)
-- returns 1 if the creature card  has the ability nCharacteristic 
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add(FE_TYPE, OP_IS, CARD_TYPE_CREATURE)
  oFilter:Add(FE_CHARACTERISTIC, OP_HAS, nCharacteristic)
  oFilter:Add(FE_CARD_INSTANCE, OP_IS, nCreature)
  if (oFilter:Count() > 0) then
    return 1
  end
  return 0
end

CheckCardByNameControlledByOpponents = function(nCardName)
-- returns 1 if there is at least one creature on battlefield controlled by opponents with the name nCardName.
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add(FE_TYPE, OP_IS, CARD_TYPE_CREATURE)
  oFilter:Add( FE_CARD_NAME, OP_IS, nCardName ) 
  oFilter:Add( FE_TEAM, OP_NOT, EffectController():GetTeam() )
  if (oFilter:Count() > 0) then
    return 1
  end
  return 0
end

CheckCardByNameControlledBy = function(nCardName, nPlayer)
-- returns 1 if there is at least one creature on battlefield controlled by nPlayer with the name nCardName.
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add(FE_TYPE, OP_IS, CARD_TYPE_CREATURE)
  oFilter:Add( FE_CARD_NAME, OP_IS, nCardName ) 
  oFilter:Add(FE_CONTROLLER, OP_IS, nPlayer)
  if (oFilter:Count() > 0) then
    return 1
  end
  return 0
end

CountCardByNameControlledBy = function(nCardName, nZone, nPlayer)
-- returns the number of card with the name nCardName if there is at least one battlefield controlled by nPlayer.
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add( FE_CARD_NAME, OP_IS, nCardName ) 
  oFilter:Add(FE_CONTROLLER, OP_IS, nPlayer)
  oFilter:SetZone( nZone, nPlayer )
  if (oFilter:Count() > 0) then
    return oFilter:Count()
  end
  return 0
end

CountcardTypeControlledBy = function(nType, nPlayer, nZone)
-- returns the number of card of the TYPE (nTYPE), controlled by (nPlayer), considering the zone (nZone) 
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add(FE_TYPE, OP_IS, nType)
  oFilter:Add(FE_CONTROLLER, OP_IS, nPlayer)
  oFilter:SetZone( nZone, nPlayer )
  if (oFilter:Count() > 0) then
    return oFilter:Count()
  end
  return 0
end

CountPermanentCardsControlledBy = function(nPlayer)
-- returns the number of permanents controlled by (nPlayer)
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add( FE_IS_PERMANENT, true )
  oFilter:Add(FE_CONTROLLER, OP_IS, nPlayer)
  oFilter:SetZone( ZONE_BATTLEFIELD, nPlayer )
  if (oFilter:Count() > 0) then
    return oFilter:Count()
  end
  return 0
end


CountcardTypeInToZone = function(nType, nZone)
-- returns the number of card of the TYPE (nTYPE), considering the zone (nZone) 
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add(FE_TYPE, OP_IS, nType)
  oFilter:Add(FE_CONTROLLER, OP_IS, nPlayer)
  oFilter:SetZone( nZone )
  if (oFilter:Count() > 0) then
    return oFilter:Count()
  end
  return 0
end

CountBasicLandsSubtypeControlledBy = function(nType, nPlayer, nZone)
-- returns the number of basic land cards of the SUBTYPE (nTYPE), controlled by (nPlayer), considering the zone (nZone) 
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add( FE_SUPERTYPE, OP_IS, SUPERTYPE_BASIC )
  oFilter:Add( FE_TYPE, OP_IS, CARD_TYPE_LAND )
  oFilter:Add(FE_SUBTYPE, OP_IS, nType)
  oFilter:Add(FE_CONTROLLER, OP_IS, nPlayer)
  oFilter:SetZone( nZone, nPlayer )
  if (oFilter:Count() > 0) then
    return oFilter:Count()
  end
  return 0
end

CountActionCreaturesControlledBy = function(nAction, nPlayer, nZone)
-- returns the number of Creatures,doing nAction, controlled by (nPlayer), considering the zone (nZone) 
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add(nAction, true)
  oFilter:Add(FE_TYPE, OP_IS, CARD_TYPE_CREATURE)
  oFilter:Add(FE_CONTROLLER, OP_IS, nPlayer)
  oFilter:SetZone( nZone, nPlayer )
  if (oFilter:Count() > 0) then
    return oFilter:Count()
  end
  return 0
end


CheckThisCreatureInZoneForCharacteristic = function(nCard, nZone, nPlayer, nCharacteristic)
-- returns 1 if EffectSource card  has the ability nCharacteristic 
-- else returns 0

  local oFilter = ClearFilter()
  oFilter:Add(FE_TYPE, OP_IS, CARD_TYPE_CREATURE)
  oFilter:Add(FE_CHARACTERISTIC, OP_HAS, nCharacteristic)
  oFilter:SetZone( nZone, nPlayer )
  oFilter:Add(FE_CARD_INSTANCE, OP_IS, nCard)
  if (oFilter:Count() > 0) then
    return 1
  end
  return 0
end


GreaterManaCountByColourInHand = function(nColour, nPlayer)
 local player = nPlayer
    local filter = ClearFilter()
    local number = player:Hand_Count()
    local TempLands = 0
    local CurrentChromaCount = 0
     for i = 0, (number-1) do
         local card = player:Hand_GetNth(i)
         if card ~= nil then
             filter:Clear()
             filter:SetZone(ZONE_HAND, player)
             filter:Add(FE_CARD_INSTANCE, OP_IS, card) 
             CurrentChromaCount =  filter:ChromaCount(nColour)
               if (CurrentChromaCount > TempLands) then
                   TempLands = CurrentChromaCount
               end
        end
    end
return TempLands
end



ColourManaCountIntoCard = function(nColour, nCard, nPlayer)
local filter = ClearFilter()
    local CurrentChromaCount = 0
         if nCard ~= nil then
	     filter:Clear()
             local filter = ClearFilter()
	     filter:SetZone(ZONE_HAND, nPlayer)
             filter:Add(FE_CARD_INSTANCE, OP_IS, nCard) 
             CurrentChromaCount =  filter:ChromaCount(nColour)
               if (CurrentChromaCount > 0) then
                   return CurrentChromaCount
               else
                   return 0
               end
        else
	    return 0
        end
end



CountHowManyTargets = function(oIndex)
local count_so_far = 0
   for i=0, 99 do
       local target = EffectDC():Get_Targets(oIndex) and EffectDC():Get_Targets(oIndex):Get_CardPtr(i)
       if target ~= nil then
        count_so_far = count_so_far + 1
        end
  end
  if (count_so_far > 0) then
    return count_so_far
  else
    return 0
  end
end

NumbersToString = function(oVal)
local oString = ""
if oVal == 1 then
   oString = "A"
elseif oVal == 2 then
   oString = "B"
elseif oVal == 3 then
   oString = "C"
elseif oVal == 4 then
   oString = "D"
elseif oVal == 5 then
   oString = "E"
elseif oVal == 6 then
   oString = "F"
elseif oVal == 7 then
   oString = "G"
elseif oVal == 8 then
   oString = "H"
elseif oVal == 9 then
   oString = "I"
elseif oVal == 10 then
   oString = "J"
elseif oVal == 11 then
   oString = "K"
elseif oVal == 12 then
   oString = "L"
elseif oVal == 13 then
   oString = "M"
elseif oVal == 14 then
   oString = "N"
elseif oVal == 15 then
   oString = "O"
elseif oVal == 16 then
   oString = "P"
elseif oVal == 17 then
   oString = "Q"
elseif oVal == 18 then
   oString = "R"
elseif oVal == 19 then
   oString = "S"
elseif oVal == 20 then
   oString = "T"
elseif oVal == 21 then
   oString = "U"
elseif oVal == 22 then
   oString = "V"
elseif oVal == 23 then
   oString = "W"
elseif oVal == 24 then
   oString = "X"
elseif oVal == 25 then
   oString = "Y"
elseif oVal == 26 then
   oString = "Z"
elseif oVal == 27 then
   oString = "_"
elseif oVal == 28 then
   oString = " "
end
return oString
end

StringToCreatureIndex = function(oVal)
local oString = 0
if oVal == "HUMAN" or oVal == "HUMAIN" or oVal == "HUMANO" or oVal == "MENSCH" or oVal == "UMANO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 0
elseif oVal == "ADVISOR" or oVal == "CONSEILLER" or oVal == "CONSEJERO" or oVal == "BERATER" or oVal == "CONSIGLIERE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 1
elseif oVal == "ANEMONE" or oVal == "ANEMONA" or oVal == "SEEANEMONE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 2
elseif oVal == "ANGEL" or oVal == "ANGE" or oVal == "ANGEL" or oVal == "ENGEL" or oVal == "ANGELO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 3
elseif oVal == "ANTEATER" or oVal == "FOURMILIER" or oVal == "HORMIGUERO" or oVal == "AMEISENBAR" or oVal == "FORMICHIERE"   then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 4
elseif oVal == "ANTELOPE" or oVal == "ANTILOPE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 5
elseif oVal == "APE" or oVal == "GRAND SINGE" or oVal == "SIMIO" or oVal == "MENSCHENAFFE" or oVal == "SCIMPANZE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 6
elseif oVal == "ARCHER" or oVal == "ARQUERO" or oVal == "BOGENSCHUTZE" or oVal == "ARCIERE"   then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 7
elseif oVal == "ARCHON"  or oVal == "ARCHONTE" or oVal == "ARCONTE" or oVal == "ARCHON"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 8
elseif oVal == "ARTIFICER"  or oVal == "ARTIFICIER" or oVal == "ARTIFICE" or oVal == "HANDWERKER" or oVal == "ARTEFICE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 9
elseif oVal == "ASSASSIN"  or oVal == "ASESINO" or oVal == "ASSASSINE" or oVal == "ASSASSINO"   then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 10
elseif oVal == "ASSEMBLY WORKER"  or oVal == "OUVRIER SPECIALISE" or oVal == "OPERARIO" or oVal == "MONTAGEARBEITER" or oVal == "ADDETTO AL MONTAGGIO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 11
elseif oVal == "ATOG" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 12
elseif oVal == "AUROCHS"  or oVal == "URO" or oVal == "AUEROCHSE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 13
elseif oVal == "AVATAR" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 14
elseif oVal == "BADGER" or oVal == "BLAIREAU" or oVal == "TEJON" or oVal == "DACHS" or oVal == "TASSO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 15
elseif oVal == "BARBARIAN" or oVal == "BARBARE" or oVal == "BARBARO" or oVal == "BARBAR" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 16
elseif oVal == "BASILISK"  or oVal == "BASILIC" or oVal == "BASILISCO" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 17
elseif oVal == "BAT"  or oVal == "CHAUVE SOURIS" or oVal == "MURCIELAGO" or oVal == "FLEDERMAUS" or oVal == "PIPISTRELLO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 18
elseif oVal == "BEAR"  or oVal == "OURS" or oVal == "OSO" or oVal == "BAR" or oVal == "ORSO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 19
elseif oVal == "BEAST"  or oVal == "BTE" or oVal == "BESTIA" or oVal == "BESTIE" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 20
elseif oVal == "BEEBLE"  or oVal == "BIBULE" or oVal == "BEEBLE" or oVal == "BOBBEL" or oVal == "BIBOLO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 21
elseif oVal == "BERSERKER" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 22
elseif oVal == "BIRD" or oVal == "OISEAU" or oVal == "AVE" or oVal == "VOGEL" or oVal == "UCCELLO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 23
elseif oVal == "BLINKMOTH"  or oVal == "SCINTIMITE" or oVal == "POLILLA TITILANTE" or oVal == "BLINKMOTTE" or oVal == "LAMPIDOTTERO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 24
elseif oVal == "BOAR"  or oVal == "SANGLIER" or oVal == "JABALI" or oVal == "WILDSCHWEIN" or oVal == "CINGHIALE"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 25
elseif oVal == "BRINGER"  or oVal == "ANNONCIATEUR" or oVal == "ADALID" or oVal == "PORTATORE" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 26
elseif oVal == "BRUSHWAGG"  or oVal == "BOSQUERISSON" or oVal == "YERBAMALA" or oVal == "BUSCHKOTER" or oVal == "BURLARBUSTO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 27
elseif oVal == "CAMARID"  or oVal == "CAMARIDE" or oVal == "CAMARIDO" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 28
elseif oVal == "CAMEL"  or oVal == "CHAMEAU" or oVal == "CAMELLO" or oVal == "KAMEL" or oVal == "CAMMELLO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 29
elseif oVal == "CARIBOU"  or oVal == "CARIBU" or oVal == "RENTIER" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 30
elseif oVal == "CARRIER"  or oVal == "PROPAGATEUR" or oVal == "PORTADOR" or oVal == "UBERTRAGER" or oVal == "VIAGGIATORE"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 31
elseif oVal == "CAT"  or oVal == "CHAT" or oVal == "FELINO" or oVal == "KATZE" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 32
elseif oVal == "CENTAUR"  or oVal == "CENTAURE" or oVal == "CENTAURO" or oVal == "ZENTAUR" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 33
elseif oVal == "CEPHALID"  or oVal == "CEPHALIDE" or oVal == "CEFALIDO" or oVal == "ZEPHALID" or oVal == "CEFALIDE"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 34
elseif oVal == "CHIMERA"  or oVal == "CHIMERE" or oVal == "QUIMERA" or oVal == "CHIMARE" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 35
elseif oVal == "CITIZEN"  or oVal == "CITOYEN" or oVal == "CIUDADANO" or oVal == "BURGER" or oVal == "CITTADINO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 36
elseif oVal == "CLERIC"  or oVal == "CLERC" or oVal == "CLERIGO" or oVal == "KLERIKER" or oVal == "CHIERICO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 37
elseif oVal == "COCKATRICE"  or oVal == "COCATRIX" or oVal == "COCATRIZ" or oVal == "WOLPERTINGER" or oVal == "COCCATRICE"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 38
elseif oVal == "CONSTRUCT"  or oVal == "CONSTRUCTION" or oVal == "CONSTRUCTO" or oVal == "KONSTRUKT" or oVal == "COSTRUTTO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 39
elseif oVal == "COWARD"  or oVal == "COUARD" or oVal == "COBARDE" or oVal == "FEIGLING" or oVal == "VIGLIACCO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 40
elseif oVal == "CRAB"  or oVal == "CRABE" or oVal == "CANGREJO" or oVal == "KRABBE" or oVal == "GRANCHIO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 41
elseif oVal == "CROCODILE"  or oVal == "COCODRILO" or oVal == "KROKODIL" or oVal == "COCCODRILLO" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 42
elseif oVal == "CYCLOPS"  or oVal == "CYCLOPE" or oVal == "ZYKLOP" or oVal == "CICLOPE" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 43
elseif oVal == "DAUTHI" or oVal == "DAUTI" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 44
elseif oVal == "DEMON" or oVal == "DEMONIO" or oVal == "DAMON" or oVal == "DEMONE"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 45
elseif oVal == "DESERTER"  or oVal == "DESERTEUR" or oVal == "DESERTOR" or oVal == "DISERTORE" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 46
elseif oVal == "DEVIL" or oVal == "DIABLE" or oVal == "DIABLO" or oVal == "TEUFEL" or oVal == "DIAVOLO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 47
elseif oVal == "DJINN" or oVal == "DSCHINN" or oVal == "GENIO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 48
elseif oVal == "DRAGON" or oVal == "DRACHE" or oVal == "DRAGO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 49
elseif oVal == "DRAKE" or oVal == "DRAKON" or oVal == "DRACO" or oVal == "SCEADA" or oVal == "DRAGHETTO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 50
elseif oVal == "DREADNOUGHT" or oVal == "CUIRASSE" or oVal == "ACORAZADO" or oVal == "SCHLACHTSCHIFF" or oVal == "STERMINATORE"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 51
elseif oVal == "DRONE" or oVal == "ZANGANO" or oVal == "DROHNE"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 52
elseif oVal == "DRUID" or oVal == "DRUIDE" or oVal == "DRUIDA" or oVal == "DRUIDO" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 53
elseif oVal == "DRYAD" or oVal == "DRYADE" or oVal == "DRIADA" or oVal == "DRYADE" or oVal == "DRIADE"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 54
elseif oVal == "DWARF" or oVal == "NAIN" or oVal == "ENANO" or oVal == "ZWERG" or oVal == "NANO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 55
elseif oVal == "EFREET" or oVal == "EFRIT" or oVal == "IFRIT" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 56
elseif oVal == "EGG" or oVal == "EUF" or oVal == "HUEVO" or oVal == "EI" or oVal == "UOVO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 57
elseif oVal == "ELDER" or oVal == "ANCETRE" or oVal == "ANCIANO" or oVal == "ALTESTER" or oVal == "ANTICO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 58
elseif oVal == "ELEMENTAL" or oVal == "ELEMENTARWESEN" or oVal == "ELEMENTALE" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 59
elseif oVal == "ELEPHANT" or oVal == "ELEFANTE" or oVal == "ELEFANT" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 60
elseif oVal == "ELF" or oVal == "ELFE" or oVal == "ELFO" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 61
elseif oVal == "ELK" or oVal == "ELAN" or oVal == "ALCE" or oVal == "HIRSCH" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 62
elseif oVal == "EYE" or oVal == "EIL" or oVal == "OJO" or oVal == "BETRACHTER" or oVal == "OCCHIO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 63
elseif oVal == "FAERIE" or oVal == "PEUPLE FEE" or oVal == "HADA" or oVal == "FEENWESEN" or oVal == "SPIRITELLO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 64
elseif oVal == "FERRET" or oVal == "FURET" or oVal == "HURON" or oVal == "FRETTCHEN" or oVal == "FURETTO"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 65
elseif oVal == "FISH" or oVal == "POISSON" or oVal == "PEZ" or oVal == "FISCH" or oVal == "PESCE"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 66
elseif oVal == "FLAGBEARER" or oVal == "ENSEIGNE" or oVal == "ABANDERADO" or oVal == "FAHNENTRAGER" or oVal == "PORTABANDIERA"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 67
elseif oVal == "FOX" or oVal == "RENARD" or oVal == "ZORRO" or oVal == "FUCHS" or oVal == "VOLPE"  then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 68
elseif oVal == "FROG" or oVal == "GRENOUILLE" or oVal == "RANA" or oVal == "FROSCH" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 69
elseif oVal == "FUNGUS" or oVal == "FONGUS" or oVal == "HONGO" or oVal == "PILZWESEN" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 70
elseif oVal == "GARGOYLE" or oVal == "GARGOUILLE" or oVal == "GARGOLA" then 
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 71
elseif oVal == "GIANT" or oVal == "" or oVal == "" or oVal == "" or oVal == ""  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 72
elseif oVal == "GNOME" or oVal == "GEANT" or oVal == "GIGANTE" or oVal == "RIESE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 73
elseif oVal == "GOAT" or oVal == "CHEVRE" or oVal == "CABRA" or oVal == "ZIEGE" or oVal == "CAPRA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 74
elseif oVal == "GOBLIN" or oVal == "GOBELIN" or oVal == "TRASGO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 75
elseif oVal == "GOLEM" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 76
elseif oVal == "GORGON" or oVal == "GORGONOIDE" or oVal == "GORGONA" or oVal == "GORGO" or oVal == "GORGONE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 77
elseif oVal == "GRAVEBORN" or oVal == "NE DES TOMBES" or oVal == "CADAVER" or oVal == "LEICHE" or oVal == "FIGLIO DELLA TOMBA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 78
elseif oVal == "GREMLIN" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 79
elseif oVal == "GRIFFIN" or oVal == "GRIFFON" or oVal == "GRIFO" or oVal == "GREIF" or oVal == "GRIFONE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 80
elseif oVal == "HAG" or oVal == "MEGERE" or oVal == "SAGA" or oVal == "VETTEL" or oVal == "STREGA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 81
elseif oVal == "HARPY" or oVal == "HARPIE" or oVal == "ARPIA" or oVal == "HARPYIE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 82
elseif oVal == "HELLION" or oVal == "MONSTRUOSITE" or oVal == "INFERNAL" or oVal == "TEUFELSBRATEN" or oVal == "INFERNALE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 83
elseif oVal == "HIPPO" or oVal == "HIPPOPOTAME" or oVal == "HIPOPOTAMO" or oVal == "FLUSSPFERD" or oVal == "IPPOPOTAMO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 84
elseif oVal == "HOMARID" or oVal == "HOMARIDE" or oVal == "HOMARIDO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 85
elseif oVal == "HOMUNCULUS" or oVal == "HOMONCULE" or oVal == "HOMUNCULO" or oVal == "HOMUNKULUS" or oVal == "OMUNCOLO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 86
elseif oVal == "HORROR" or oVal == "HORREUR" or oVal == "SCHRECKEN" or oVal == "ORRORE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 87
elseif oVal == "HORSE" or oVal == "CHEVAL" or oVal == "CABALLO" or oVal == "PFERD" or oVal == "CAVALLO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 88
elseif oVal == "HOUND" or oVal == "CHIEN DE CHASSE" or oVal == "PERRO" or oVal == "HUND" or oVal == "SEGUGIO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 89
elseif oVal == "HYDRA" or oVal == "HYDRE" or oVal == "HIDRA" or oVal == "IDRA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 90
elseif oVal == "ILLUSION" or oVal == "ILUSION" or oVal == "ILLUSIONE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 91
elseif oVal == "IMP" or oVal == "DIABLOTIN" or oVal == "DIABLILLO" or oVal == "BOLD" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 92
elseif oVal == "INCARNATION" or oVal == "ENCARNACION" or oVal == "INKARNATION" or oVal == "INCARNAZIONE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 93
elseif oVal == "INSECT" or oVal == "INSECTE" or oVal == "INSECTO" or oVal == "INSEKT" or oVal == "INSETTO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 94
elseif oVal == "JELLYFISH" or oVal == "MEDUSE" or oVal == "MEDUSA" or oVal == "QUALLE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 95
elseif oVal == "JUGGERNAUT" or oVal == "DJAGGERNAUT" or oVal == "DESTRUCTOR" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 96
elseif oVal == "KAVU" or oVal == "KAVRU" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 97
elseif oVal == "KIRIN" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 98
elseif oVal == "KITHKIN" or oVal == "SANGAMI" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 99
elseif oVal == "KNIGHT" or oVal == "CHEVALIER" or oVal == "CABALLERO" or oVal == "RITTER" or oVal == "CAVALIERE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 100
elseif oVal == "KOBOLD" or oVal == "COBOLDO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 101
elseif oVal == "KOR" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 102
elseif oVal == "KRAKEN" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 103
elseif oVal == "LAMMASU" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 104
elseif oVal == "LEECH" or oVal == "SANGSUE" or oVal == "SANGUIJUELA" or oVal == "EGEL" or oVal == "SANGUISUGA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 105
elseif oVal == "LEVIATHAN" or oVal == "LEVIATN" or oVal == "LEVIATANO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 106
elseif oVal == "LHURGOYF" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 107
elseif oVal == "LICID" or oVal == "LITIQUE" or oVal == "LICIDO" or oVal == "ZECKE" or oVal == "LICIDE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 108
elseif oVal == "LIZARD" or oVal == "LEZARD" or oVal == "LAGARTO" or oVal == "EIDECHSE" or oVal == "LUCERTOLA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 109
elseif oVal == "MANTICORE" or oVal == "MANTICORA" or oVal == "MANTIKOR" or oVal == "MANTICORA" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 110
elseif oVal == "MASTICORE" or oVal == "MASTIKOR" or oVal == "MASTICORA" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 111
elseif oVal == "MERCENARY" or oVal == "MERCENAIRE" or oVal == "MERCENARIO" or oVal == "SLDNER" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 112
elseif oVal == "MERFOLK" or oVal == "ONDIN" or oVal == "TRITON" or oVal == "MEERVOLK" or oVal == "TRITONE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 113
elseif oVal == "METATHRAN" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 114
elseif oVal == "MINION" or oVal == "MIGNON" or oVal == "SICARIO" or oVal == "DIENER" or oVal == "SERVITORE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 115
elseif oVal == "MINOTAUR" or oVal == "MINOTAURE" or oVal == "MINOTAURO" or oVal == "MINOTAURUS"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 116
elseif oVal == "MONGER" or oVal == "NEGOCIANT" or oVal == "TRAFICANTE" or oVal == "FREIHANDLER" or oVal == "COMMERCIANTE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 117
elseif oVal == "MONGOOSE" or oVal == "MANGOUSTE" or oVal == "MANGOSTA" or oVal == "MUNGO" or oVal == "MANGUSTA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 118
elseif oVal == "MONK" or oVal == "MOINE" or oVal == "MONJE" or oVal == "MONCH" or oVal == "MONACO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 119
elseif oVal == "MOONFOLK" or oVal == "LUNAREEN" or oVal == "PUEBLO LUNAR" or oVal == "MONDVOLK" or oVal == "LUNANTROPO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 120
elseif oVal == "MUTANT" or oVal == "MUTANTE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 121
elseif oVal == "MYR" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 122
elseif oVal == "MYSTIC" or oVal == "MYSTIQUE" or oVal == "MYSTIKER" or oVal == "MISTICO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 123
elseif oVal == "NAUTILUS" or oVal == "NAUTILE" or oVal == "NAUTILO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 124
elseif oVal == "NEPHILIM" or oVal == "NEFILIM" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 125
elseif oVal == "NIGHTMARE" or oVal == "CAUCHEMAR" or oVal == "PESADILLA" or oVal == "NACHTMAHR" or oVal == "INCUBO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 126
elseif oVal == "NIGHTSTALKER" or oVal == "CHASSENUIT" or oVal == "CAZADOR NOCTURNO" or oVal == "NACHTSCHRAT" or oVal == "CACCIATORE NOTTURNO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 127
elseif oVal == "NINJA" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 128
elseif oVal == "NOMAD" or oVal == "NOMADE" or oVal == "NOMADA" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 129
elseif oVal == "OCTOPUS" or oVal == "PIEUVRE" or oVal == "PULPO" or oVal == "OKTOPUS" or oVal == "PIOVRA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 130
elseif oVal == "OGRE" or oVal == "OGRO" or oVal == "OGER" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 131
elseif oVal == "OOZE" or oVal == "LIMON" or oVal == "CIENO" or oVal == "SCHLAMMWESEN" or oVal == "MELMA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 132
elseif oVal == "ORB" or oVal == "ORBE" or oVal == "SPHARE" or oVal == "GLOBO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 133
elseif oVal == "ORC" or oVal == "ORQUE" or oVal == "ORCO" or oVal == "ORK" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 134
elseif oVal == "ORGG" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 135
elseif oVal == "OUPHE" or oVal == "ORPHE" or oVal == "OUFE" or oVal == "BUBOH" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 136
elseif oVal == "OX" or oVal == "BOVIDE" or oVal == "BUEY" or oVal == "OCHSE" or oVal == "BUE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 137
elseif oVal == "OYSTER" or oVal == "HUITRE" or oVal == "OSTRA" or oVal == "AUSTER" or oVal == "OSTRICA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 138
elseif oVal == "PEGASUS" or oVal == "PEGASE" or oVal == "PEGASO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 139
elseif oVal == "PENTAVITE" or oVal == "PENTAVITA" or oVal == "PENTAVIT" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 140
elseif oVal == "PEST" or oVal == "PARASITE" or oVal == "PLAGA" or oVal == "SCHADLING" or oVal == "PESTE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 141
elseif oVal == "PHELDDAGRIF" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 142
elseif oVal == "PHOENIX" or oVal == "PHENIX" or oVal == "FENIX" or oVal == "FENICE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 143
elseif oVal == "PINCHER" or oVal == "PINCEUR" or oVal == "TENAZA" or oVal == "KNEIFER" or oVal == "PUNGITORE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 144
elseif oVal == "PIRATE" or oVal == "PIRATA" or oVal == "PIRAT" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 145
elseif oVal == "PLANT" or oVal == "PLANTE" or oVal == "PLANTA" or oVal == "PFLANZE" or oVal == "PIANTA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 146
elseif oVal == "PRISM" or oVal == "PRISME" or oVal == "PRISMA" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 147
elseif oVal == "RABBIT" or oVal == "LAPIN" or oVal == "CONEJO" or oVal == "KANINCHEN" or oVal == "CONIGLIO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 148
elseif oVal == "RAT" or oVal == "RATA" or oVal == "RATTE" or oVal == "RATTO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 149
elseif oVal == "REBEL" or oVal == "REBELLE" or oVal == "REBELDE" or oVal == "REBELL" or oVal == "RIBELLE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 150
elseif oVal == "REFLECTION" or oVal == "REFLET" or oVal == "REFLEJO" or oVal == "REFLEKTION" or oVal == "RIFLESSO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 151
elseif oVal == "RHINO" or oVal == "RHINOCEROS" or oVal == "RINOCERONTE" or oVal == "NASHORN"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 152
elseif oVal == "RIGGER" or oVal == "GREEUR" or oVal == "APAREJADOR" or oVal == "MECHANIKER" or oVal == "ASSEMBLATORE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 153
elseif oVal == "ROGUE" or oVal == "GREDIN" or oVal == "BRIBON" or oVal == "RAUBER" or oVal == "FARABUTTO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 154
elseif oVal == "SALAMANDER" or oVal == "SALAMANDRE" or oVal == "SALAMANDRA" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 155
elseif oVal == "SAMURAI" or oVal == "SAMOURA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 156
elseif oVal == "SAND" or oVal == "SABLE" or oVal == "ARENA" or oVal == "SABBIA" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 157
elseif oVal == "SAPROLING" or oVal == "SAPROBIONTE" or oVal == "SAPROLIN" or oVal == "SAPROLINGIO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 158
elseif oVal == "SATYR" or oVal == "SATYRE" or oVal == "SATIRO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 159
elseif oVal == "SCARECROW" or oVal == "EPOUVANTAIL" or oVal == "ESPANTAPAJAROS" or oVal == "VOGELSCHEUCHE" or oVal == "SPAVENTAPASSERI"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 160
elseif oVal == "SCORPION" or oVal == "ESCORPION" or oVal == "SKORPION" or oVal == "SCORPIONE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 161
elseif oVal == "SCOUT" or oVal == "ECLAIREUR" or oVal == "EXPLORADOR" or oVal == "SPAHER" or oVal == "ESPLORATORE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 162
elseif oVal == "SERF" or oVal == "SIERVO" or oVal == "LEIBEIGENER" or oVal == "SERVO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 163
elseif oVal == "SERPENT" or oVal == "SERPIENTE" or oVal == "SCHLANGE" or oVal == "SERPE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 164
elseif oVal == "SHADE" or oVal == "OMBRE" or oVal == "SOMBRA" or oVal == "SCHATTEN" or oVal == "OMBRA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 165
elseif oVal == "SHAMAN" or oVal == "SHAMANE" or oVal == "CHAMAN" or oVal == "SCHAMANE" or oVal == "SCIAMANO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 166
elseif oVal == "SHAPESHIFTER" or oVal == "CHANGEFORME" or oVal == "METAMORFO" or oVal == "GESTALTWANDLER" or oVal == "POLIMORFO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 167
elseif oVal == "SHEEP" or oVal == "MOUTON" or oVal == "OVEJA" or oVal == "SCHAF" or oVal == "PECORA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 168
elseif oVal == "SKELETON" or oVal == "SQUELETTE" or oVal == "ESQUELETO" or oVal == "SKELETT" or oVal == "SCHELETRO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 169
elseif oVal == "SLITH" or oVal == "SLIT" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 170
elseif oVal == "SLIVER" or oVal == "SLIVOIDE" or oVal == "FRAGMENTADO" or oVal == "REMASURI" or oVal == "TRAMUTANTE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 171
elseif oVal == "SLUG" or oVal == "LIMACE" or oVal == "BABOSA" or oVal == "SCHNECKE" or oVal == "LUMACA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 172
elseif oVal == "SNAKE" or oVal == "SERPENT" or oVal == "VIBORA" or oVal == "OPHIS" or oVal == "SERPENTE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 173
elseif oVal == "SOLDIER" or oVal == "SOLDAT" or oVal == "SOLDADO" or oVal == "SOLDATO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 174
elseif oVal == "SOLTARI"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 175
elseif oVal == "SPAWN" or oVal == "ENGEANCE" or oVal == "ENGENDRO" or oVal == "LAICH" or oVal == "PROGENIE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 176
elseif oVal == "SPECTER" or oVal == "SPECTRE" or oVal == "ESPECTRO" or oVal == "SPETTRO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 177
elseif oVal == "SPELLSHAPER" or oVal == "SORTISAN" or oVal == "CAMBIAHECHIZOS" or oVal == "SPRUCHWANDLER" or oVal == "MUTAMAGIA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 178
elseif oVal == "SPHINX" or oVal == "ESFINGE" or oVal == "SFINGE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 179
elseif oVal == "SPIDER" or oVal == "ARAIGNEE" or oVal == "ARANA" or oVal == "SPINNE" or oVal == "RAGNO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 180
elseif oVal == "SPIKE" or oVal == "EPIX" or oVal == "PERFORADOR" or oVal == "STACHEL" or oVal == "PUNGIGLIONE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 181
elseif oVal == "SPIRIT" or oVal == "ESPRIT" or oVal == "ESPIRITU" or oVal == "GEIST" or oVal == "SPIRITO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 182
elseif oVal == "SPLINTER" or oVal == "FRAGMENT" or oVal == "ASTILLADO" or oVal == "SPLITTER" or oVal == "SCHEGGIA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 183
elseif oVal == "SPONGE" or oVal == "EPONGE" or oVal == "ESPONJA" or oVal == "SCHWAMM" or oVal == "SPUGNA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 184
elseif oVal == "SQUID" or oVal == "CALAMAR" or oVal == "KALMAR" or oVal == "CALAMARO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 185
elseif oVal == "SQUIRREL" or oVal == "ECUREUIL" or oVal == "ARDILLA" or oVal == "EICHHORNCHEN" or oVal == "SCOIATTOLO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 186
elseif oVal == "STARFISH" or oVal == "ETOILE DE MER" or oVal == "ESTRELLA DE MAR" or oVal == "SEESTERN" or oVal == "STELLA MARINA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 187
elseif oVal == "SURVIVOR" or oVal == "SURVIVANT" or oVal == "SOBREVIVIENTE" or oVal == "UBERLEBENDER" or oVal == "SOPRAVVISSUTO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 188
elseif oVal == "TETRAVITE" or oVal == "TETRAVITA" or oVal == "TETRAVIT" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 189
elseif oVal == "THALAKOS" or oVal == "TALAKO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 190
elseif oVal == "THOPTER" or oVal == "MECANOPTERE" or oVal == "TOPTERO" or oVal == "TOTTERO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 191
elseif oVal == "THRULL" or oVal == "SRANE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 192
elseif oVal == "TREEFOLK" or oVal == "SYLVIN" or oVal == "PUEBLO ARBOREO" or oVal == "BAUMHIRTE" or oVal == "SILVANTROPO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 193
elseif oVal == "TRISKELAVITE" or oVal == "TRISQUELAVITA" or oVal == "TRISKELAVIT" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 194
elseif oVal == "TROLL" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 195
elseif oVal == "TURTLE" or oVal == "TORTUE" or oVal == "TORTUGA" or oVal == "SCHILDKROTE" or oVal == "TARTARUGA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 196
elseif oVal == "UNICORN" or oVal == "LICORNE" or oVal == "UNICORNIO" or oVal == "EINHORN" or oVal == "UNICORNO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 197
elseif oVal == "VAMPIRE" or oVal == "VAMPIRO" or oVal == "VAMPIR" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 198
elseif oVal == "VEDALKEN" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 199
elseif oVal == "VIASHINO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 200
elseif oVal == "VOLVER" or oVal == "EVOLIEN" or oVal == "MODULON" or oVal == "VOLVERO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 201
elseif oVal == "WALL" or oVal == "MUR" or oVal == "MURO" or oVal == "MAUER" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 202
elseif oVal == "WARRIOR" or oVal == "GUERRIER" or oVal == "GUERRERO" or oVal == "KRIEGER" or oVal == "GUERRIERO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 203
elseif oVal == "WEIRD" or oVal == "ANOMALIE" or oVal == "EXTRANO" or oVal == "SELTSAMKEIT" or oVal == "BIZZARRIA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 204
elseif oVal == "WHALE" or oVal == "BALEINE" or oVal == "BALLENA" or oVal == "WAL" or oVal == "BALENA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 205
elseif oVal == "WIZARD" or oVal == "SORCIER" or oVal == "HECHICERO" or oVal == "ZAUBERER" or oVal == "MAGO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 206
elseif oVal == "WOLF" or oVal == "LOUP" or oVal == "LOBO" or oVal == "LUPO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 207
elseif oVal == "WOLVERINE" or oVal == "GLOUTON" or oVal == "GLOTON" or oVal == "VIELFRAB" or oVal == "GHIOTTONE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 208
elseif oVal == "WOMBAT" or oVal == "VOMBATO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 209
elseif oVal == "WORM" or oVal == "VER" or oVal == "GUSANO" or oVal == "WURMCHEN" or oVal == "VERME"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 210
elseif oVal == "WRAITH" or oVal == "APPARITION" or oVal == "APARICION" or oVal == "NECROSPETTRO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 211
elseif oVal == "WURM" or oVal == "GUIVRE" or oVal == "SIERPE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 212
elseif oVal == "YETI" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 213
elseif oVal == "ZOMBIE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 214
elseif oVal == "ZUBERA" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 215
elseif oVal == "ALLY" or oVal == "ALLIE" or oVal == "ALIADO" or oVal == "VERBUNDETER" or oVal == "ALLEATO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 216
elseif oVal == "TRAP" or oVal == "PIEGE" or oVal == "TRAMPA" or oVal == "FALLE" or oVal == "TRAPPOLA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 217
elseif oVal == "ELDRAZI"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 218
elseif oVal == "PRAETOR" or oVal == "MAGISTRADO" or oVal == "PRATOREN" or oVal == "PRETORE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 219
elseif oVal == "WEREWOLF" or oVal == "LOUP GAROU" or oVal == "LICANTROPO" or oVal == "MANNARO" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 220
elseif oVal == "SURRAKAR" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 221
elseif oVal == "GERM" or oVal == "GERME" or oVal == "GERMEN" or oVal == "KEIM" or oVal == "MICROBO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 222
elseif oVal == "HIPPOGRIFF" or oVal == "HIPPOGRIFFE" or oVal == "HIPOGRIFO" or oVal == "HIPPOGRYPH" or oVal == "IPPOGRIFO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 223
elseif oVal == "SIREN" or oVal == "SIRENE" or oVal == "SIRENA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 224
elseif oVal == "TOWNSFOLK" or oVal == "CITADIN" or oVal == "ALDEANO" or oVal == "STADTBEWOHNER" or oVal == "CITTADINI"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 225
elseif oVal == "HYENA" or oVal == "HYENE" or oVal == "HIENA" or oVal == "HYANE" or oVal == "IENA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 226
elseif oVal == "NOGGLE" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 227
elseif oVal == "GOD" or oVal == "DIEU" or oVal == "DEIDAD" or oVal == "GOTT" or oVal == "DIO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 228
elseif oVal == "NYMPH" or oVal == "NYMPHE" or oVal == "NINFA" then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 229
elseif oVal == "SABLE" or oVal == "ZIBELINE" or oVal == "MARTA" or oVal == "ZOBEL" or oVal == "ZIBELLINO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 230
elseif oVal == "DIVINITY" or oVal == "DIVINITE" or oVal == "DIVINIDAD" or oVal == "GOTTLICHKEIT" or oVal == "DIVINITA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 231
elseif oVal == "DEMIGOD" or oVal == "DEMIDIEU" or oVal == "SEMIDIOS" or oVal == "HALBGOTT" or oVal == "SEMIDIO"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 232
elseif oVal == "MINOR DIVINITY" or oVal == "DIVINITE MINEURE" or oVal == "MENOR DEIDAD" or oVal == "KLEINERE GOTTHEIT" or oVal == "DIVINITA MINORE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 233
elseif oVal == "EAGLE" or oVal == "AIGLE" or oVal == "AGUILA" or oVal == "ADLER" or oVal == "AQUILA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 234
elseif oVal == "AMAZON" or oVal == "AMAZONAS" or oVal == "AMAZZONE"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 235
elseif oVal == "QUEEN" or oVal == "REINE" or oVal == "REINA" or oVal == "KONIGIN" or oVal == "REGINA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 236
elseif oVal == "STATUE" or oVal == "ESTATUA" or oVal == "STATUA"  then
   oString = SIZE_OF_TYPE_BAND * CARD_TYPE_CREATURE + 237
end
 if oString > 999 and oString < 1238 then
   return oString
 else
   return 0
 end
end



